# -*- coding: utf-8 -*-


class BcuWsError(Exception):
    def __init__(self, code, message):
        self.message = "Código {0}: {1}".format(
            str(code),
            str(message)
        )



from setuptools import setup

setup(
    name='py_bcu',
    version='1.0.0',
    packages=['py_bcu'],
    package_dir={'': '.'},
    url='https://github.com/martinmanzo/py_bcu/',
    license='MIT',
    author='Martin Manzo',
    author_email='',
    description='Interact with the BCU\'s (Banco Central del Uruguay) webservices.',
    install_requires=[
        'zeep==3.2.0'
    ]
)
